﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.ComponentModel;

namespace xamDataGrid
{
    public class Product : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        private int _productId;
        private string _productName;
        private int _categoryId;
        private string _quantityPerUnit;
        private decimal _unitPrice;
        private int _unitsInStock;
        private int _unitsOnOrder;
        private int _reorderLevel;
        private bool _discontinued;

        public int ProductID
        {
            get
            {
                return this._productId;
            }
            set
            {
                if (this._productId != value)
                {
                    this._productId = value;
                    OnPropertyChanged("ProductID");
                }
            }
        }

        public string ProductName
        {
            get
            {
                return this._productName;
            }
            set
            {
                if (this._productName != value)
                {
                    this._productName = value;
                    OnPropertyChanged("ProductName");
                }
            }
        }

        public int CategoryID
        {
            get
            {
                return this._categoryId;
            }
            set
            {
                if (this._categoryId != value)
                {
                    this._categoryId = value;
                    OnPropertyChanged("CategoryID");
                }
            }
        }

        public string QuantityPerUnit
        {
            get
            {
                return this._quantityPerUnit;
            }
            set
            {
                if (this._quantityPerUnit != value)
                {
                    this._quantityPerUnit = value;
                    OnPropertyChanged("QuantityPerUnit");
                }
            }
        }

        public decimal UnitPrice
        {
            get
            {
                return this._unitPrice;
            }
            set
            {
                if (value < 0)
                    throw new Exception("Negative numbers are not allowed.");

                this._unitPrice = value;
                OnPropertyChanged("UnitPrice");
            }
        }

        public int UnitsInStock
        {
            get
            {
                return this._unitsInStock;
            }
            set
            {
                if (value < 0)
                    throw new Exception("Negative numbers are not allowed.");

                this._unitsInStock = value;
                OnPropertyChanged("UnitsInStock");
            }
        }

        public int UnitsOnOrder
        {
            get
            {
                return this._unitsOnOrder;
            }
            set
            {
                if (this._unitsOnOrder != value)
                {
                    this._unitsOnOrder = value;
                    OnPropertyChanged("UnitsOnOrder");
                }
            }
        }

        public int ReorderLevel
        {
            get
            {
                return this._reorderLevel;
            }
            set
            {
                if (this._reorderLevel != value)
                {
                    this._reorderLevel = value;
                    OnPropertyChanged("ReorderLevel");
                }
            }
        }

        public bool Discontinued
        {
            get
            {
                return this._discontinued;
            }
            set
            {
                if (this._discontinued != value)
                {
                    this._discontinued = value;
                    OnPropertyChanged("Discontinued");
                }
            }
        }
    }
}
